@@ -65,55 +65,26 @@ def compare_ipynb_notebooks(notebook_filenames, debug):
             comparison_errors.extend(source_errors)
 
             # Ignore output containing warnings
-            remove_warning_ouput(cells[0]["outputs"],
-                                 cells[1]["outputs"],
+            debug and print_all_output(cells)
+            remove_warning_ouput(cells[0]["outputs"], cells[1]["outputs"],
                                  debug)
 
-            # Check for different number of output fields
-            output_length_errors = check_output_field_number(cells, debug)
+            # Combine stdout text outputs
+            combine_outputs_std(cells, "stdout", debug)
+            combine_outputs_std(cells, "stderr", debug)
 
-            comparison_errors.extend(output_length_errors)
+            # Check for different number of output fields
+            if not ignore_output_differences:
+                output_length_errors = check_output_field_number(cells, debug)
+                comparison_errors.extend(output_length_errors)
 
             # Print all output, even if empty
             print_all_output(cells)
 
-            # Loop over outputs - can have multiple for each source cell
-            for outputs in zip(cells[0]["outputs"], cells[1]["outputs"]):
-
-                print(BLUE, "-".center(80, "-"), NC)
-
-                # Print the output lines
-                for idx, output in enumerate(outputs):
-                    logging.info("outputs[" + str(idx) + "] : " +
-                                 str(output))
-                    print(CYAN, "outputs[", str(idx), "]: ", NC)
-                    # Crop long output (e.g. images) to terminal
-                    print_cropped_output(output)
-
-                print(BLUE, "-".center(80, "-"), NC)
-
-                if outputs[0] == outputs[1]:
-                    print(GREEN)
-                    message = "outputs are the same"
-
-                else:
-                    # Some differences can be ignored - look closer for those
-                    comparison_pass = examine_output_diff(
-                        ignore_output_differences, outputs[0], outputs[1],
-                        debug
-                    )
-
-                    if comparison_pass:
-                        print(GREEN)
-                        message = "outputs are almost the same"
-                    else:
-                        print(RED)
-                        message = "outputs are not the same"
-                        comparison_errors.append(outputs[0])
-                        comparison_errors.append(outputs[1])
-
-                print(message, NC)
-                logging.info(message)
+            # Compare each output - can have multiple for each source cell
+            compare_outputs_errors = \
+                compare_outputs(cells, ignore_output_differences, debug)
+            comparison_errors.extend(compare_outputs_errors)
 
     # Check comparisons for errors (differences)
     comparison_result, error_message, error_content = \
@@ -122,6 +93,95 @@ def compare_ipynb_notebooks(notebook_filenames, debug):
     return comparison_result, error_message, error_content
 
 
+def compare_outputs(cells, ignore_output_differences, debug):
+
+    compare_outputs_errors = []
+
+    # Loop over outputs - can have multiple for each source cell
+    for outputs in zip(cells[0]["outputs"], cells[1]["outputs"]):
+
+        print(BLUE, "-".center(80, "-"), NC)
+
+        # Print the output lines
+        for idx, output in enumerate(outputs):
+            logging.info("outputs[" + str(idx) + "] : " +
+                         str(output))
+            print(CYAN, "outputs[", str(idx), "]: ", NC)
+            # Crop long output (e.g. images) to terminal
+            print_cropped_output(output)
+
+        print(BLUE, "-".center(80, "-"), NC)
+
+        message = ""
+        if outputs[0] == outputs[1]:
+            print(GREEN)
+            message = "outputs are the same"
+
+        else:
+            # Some differences can be ignored - look closer for those
+            comparison_pass = examine_output_diff(
+                ignore_output_differences, outputs[0], outputs[1],
+                debug
+            )
+
+            if comparison_pass:
+                print(GREEN)
+                message = "outputs are almost the same"
+            else:
+                print(RED)
+                message = "outputs are not the same"
+                compare_outputs_errors.append(outputs[0])
+                compare_outputs_errors.append(outputs[1])
+
+        print(message, NC)
+        logging.info(message)
+
+    return compare_outputs_errors
+
+
+def combine_outputs_std(cells, std_type, debug):
+    """Sometimes when a notebook is executed and a source cell contains
+       multiple print statements the outputs will be combined, and other
+       times they will not be
+       std_type == stdout or stderr"""
+
+    debug and print(GREEN, "** Entering combine_outputs_std() **\n", NC)
+    debug and print_all_output(cells)
+
+    for cell in cells:
+        combined_text = ""
+        first_index = -1
+        remove_indicies = []
+        for index, output in enumerate(cell["outputs"]):
+            if "name" in output:
+                if output["name"] == std_type:
+                    debug and print(YELLOW, "  found ", std_type, NC)
+                    if "text" in output:
+                        debug and print(CYAN, "   text: ", NC, output["text"])
+                        combined_text += output["text"]
+                        if first_index < 0:
+                            first_index = index
+                        else:
+                            remove_indicies.append(index)
+
+        if debug:
+            print("first_index:", first_index)
+            print("remove_indicies:", remove_indicies)
+            print("combined_text:", combined_text)
+
+        if len(remove_indicies) > 0:
+            # Set the combined output
+            cell["outputs"][first_index]["text"] = combined_text
+
+            # Remove specified elements from output, reverse order
+            for index in reversed(remove_indicies):
+                debug and print(CYAN, "removing index: ", index, NC)
+                cell["outputs"].pop(index)
+
+    debug and print_all_output(cells)
+    debug and print(GREEN, "** Leaving combine_outputs_std() **\n", NC)
+
+
 def check_output_field_number(cells, debug):
     output_length_errors = []
     len0 = len(cells[0]["outputs"])
@@ -169,23 +229,30 @@ def remove_warning_ouput(cells_0_outputs, cells_1_outputs, debug):
 
     # Look for the warning output and remove it from further consideration
     for outputs in [cells_0_outputs, cells_1_outputs]:
+        list_of_elements_to_remove = []
         for index, output in enumerate(outputs):
-            list_of_elements_to_remove = []
+            debug and print("index: ", index)
+            debug and print("outputs: ")
+            debug and print_cropped_output(output)
             for key in warnings_to_ignore:
                 if key in output:
                     for value in warnings_to_ignore[key]:
                         if value in output[key]:
                             debug and print(CYAN, "ignore warning", index,
-                                            value, YELLOW, "\n   ",
-                                            output[key], NC)
+                                            value, YELLOW, "\n   ")
+                            debug and print_cropped_output(output[key])
+                            debug and print(NC)
                             list_of_elements_to_remove.append(index)
 
+        if len(list_of_elements_to_remove) > 0:
             # Remove repeats of indicies
             list_of_elements_to_remove = \
                 list(dict.fromkeys(list_of_elements_to_remove))
+            debug and print(len(list_of_elements_to_remove))
+            debug and print(list_of_elements_to_remove)
 
             # Remove specified elements from array
-            for index in list_of_elements_to_remove:
+            for index in reversed(list_of_elements_to_remove):
                 debug and print(CYAN, "removing index: ", index, NC)
                 outputs.pop(index)
 
@@ -249,7 +316,8 @@ def print_comparison_results(notebook_filenames, comparison_result,
 def should_cells_be_compared(cells_0, cells_1, debug):
     """Check to see if source cell is code, is not empty"""
 
-    debug and print("cells_0:", cells_0, "\n", "cells_1:", cells_1)
+    debug and print("cells_0:", print_cropped_output(cells_0), "\n",
+                    "cells_1:", print_cropped_output(cells_1))
 
     if "cell_type" not in cells_0 or "cell_type" not in cells_1:
         return False
@@ -274,7 +342,8 @@ def should_cells_be_compared(cells_0, cells_1, debug):
 def compare_source_lines(source_line_0, source_line_1, debug):
 
     # Some output for given sources can be ignored, e.g. output from timing
-    # finctions will not be exactly the same
+    # functions will not be exactly the same
+    # ignore_output_if_source = ["timeit", "random_directions", "rot_center"]
     ignore_output_if_source = ["timeit", "random_directions"]
     ignore_output_differences = False
 
@@ -298,6 +367,7 @@ def compare_source_lines(source_line_0, source_line_1, debug):
         for source_item in ignore_output_if_source:
             if source_item in source_line_0:
                 ignore_output_differences = True
+                debug and print("will ignore output from ", source_item)
     else:
         message = "sources are not the same"
         print(RED)
@@ -464,7 +534,7 @@ def examine_output_key_text(key, nb0, nb1, debug):
         "R2019a",
         "HDF5_PLUGIN_PATH",
         "Hello",
-        "hello"
+        "hello",
     ]
 
     # Check for ouput which should always appear, but is most likely different,
